wagtail_video
=============

Requirements
------------

-  Wagtail >= 2.4


Installing
----------

Install using pypi

.. code:: bash

    pip install wagtail_video


Future features
---------------

-  Transcoding via ffmpeg